==> vod-cloud-model-1.0.0-sources.jar: com/valor/vod/cloud/model/database/ddo/MfcUserCloudPkgHistoryDdo.java <==
package com.valor.vod.cloud.model.database.ddo;


import com.valor.vod.common.database.model.AbstractLMI;

import javax.persistence.*;

//网盘包与用户的关联关系
@Entity
@Table(
    name = "mfc_user_cloud_pkg_history",indexes = {
    @Index(name = "i_mfc_user_cloud_pkg_history_account_id",columnList = "account_id"),
    //@Index(name = "i_mfc_user_cloud_pkg_history_account_type", columnList = "account_type"),
    @Index(name = "i_mfc_user_cloud_pkg_history_pkg_id", columnList = "pkg_id")}
)
public class MfcUserCloudPkgHistoryDdo extends AbstractLMI {

    @Id
    @Column(
        name = "account_id"
    )
    private Long accountId;

//    @Id
//    @Column(
//        name = "account_type"
//    )
//    private int accountType ;

    @Id
    @Column(
        name = "pkg_id"
    )
    private Long pkgId;

    @Column(
        name = "expired_time"
    )
    private Long expiredTime=0L;


    @Column(
        name = "history_time"
    )
    private Long historyTime=0L;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getHistoryTime() {
        return historyTime;
    }

    public void setHistoryTime(Long historyTime) {
        this.historyTime = historyTime;
    }

    //    public int getAccountType() {
//        return accountType;
//    }
//
//    public void setAccountType(int accountType) {
//        this.accountType = accountType;
//    }

    public Long getPkgId() {
        return pkgId;
    }

    public void setPkgId(Long pkgId) {
        this.pkgId = pkgId;
    }

    public Long getExpiredTime() {
        return expiredTime;
    }

    public void setExpiredTime(Long expiredTime) {
        this.expiredTime = expiredTime;
    }
}

==> vod-cloud-model-3.1.2-sources.jar: com/valor/vod/cloud/model/database/ddo/MfcUserCloudPkgHistoryDdo.java <==
package com.valor.vod.cloud.model.database.ddo;


import com.valor.vod.common.database.model.AbstractLMI;

import javax.persistence.*;

//网盘包与用户的关联关系
@Entity
@Table(
    name = "mfc_user_cloud_pkg_history",indexes = {
    @Index(name = "i_mfc_user_cloud_pkg_history_account_id",columnList = "account_id"),
    //@Index(name = "i_mfc_user_cloud_pkg_history_account_type", columnList = "account_type"),
    @Index(name = "i_mfc_user_cloud_pkg_history_pkg_id", columnList = "pkg_id")}
)
public class MfcUserCloudPkgHistoryDdo extends TenantAbstractLMI {

    @Id
    @Column(
        name = "account_id"
    )
    private Long accountId;

//    @Id
//    @Column(
//        name = "account_type"
//    )
//    private int accountType ;

    @Id
    @Column(
        name = "pkg_id"
    )
    private Long pkgId;

    @Column(
        name = "expired_time"
    )
    private Long expiredTime=0L;


    @Column(
        name = "history_time"
    )
    private Long historyTime=0L;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getHistoryTime() {
        return historyTime;
    }

    public void setHistoryTime(Long historyTime) {
        this.historyTime = historyTime;
    }

    //    public int getAccountType() {
//        return accountType;
//    }
//
//    public void setAccountType(int accountType) {
//        this.accountType = accountType;
//    }

    public Long getPkgId() {
        return pkgId;
    }

    public void setPkgId(Long pkgId) {
        this.pkgId = pkgId;
    }

    public Long getExpiredTime() {
        return expiredTime;
    }

    public void setExpiredTime(Long expiredTime) {
        this.expiredTime = expiredTime;
    }
}
